gcc: The GNU Compiler Collection, including the C, C++ and Fortran compiler
===========================================================================

Description
-----------

The GNU Compiler Collection, including the C, C++ and Fortran compiler.

License
-------

GPL version 2 or version 3


Upstream Contact
----------------

https://gcc.gnu.org/
